@@ -57,7 +57,10 @@ fn get_rels_from_header(headers: &reqwest::header::HeaderMap, rel: &str) -> Vec<
 }
 
 /// Resolves all of the relating links for a particular URL.
-pub async fn for_url(config: &crate::Configuration, url: &str, rel: &str) -> Vec<String> {
+pub async fn for_url<C>(config: &C, url: &str, rel: &str) -> Vec<String>
+where
+    C: crate::IConfiguration + Send + Sync,
+{
     let resp_builder = config
         .request(Some(format!(
             "Resolving rel={:?} values for the resource at this URL",
